DebugNetworkStore class

Properties

entries ValueNotifier<List<DebugNetworkEntry>>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
completeRequest({required String id, int? statusCode, Map<String, String>? responseHeaders, String? responseBody}) → void
failRequest({required String id, required String error, int? statusCode, Map<String, String>? responseHeaders, String? responseBody}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startRequest({required String method, required Uri url, required Map<String, String> requestHeaders, String? requestBody}) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DebugNetworkStore
final