DebugNetworkEntry class

Constructors

DebugNetworkEntry({required String id, required String method, required Uri url, required DateTime startedAt, required DebugNetworkRequestState state, DateTime? endedAt, int? statusCode, Map<String, String> requestHeaders = const <String, String>{}, Map<String, String> responseHeaders = const <String, String>{}, String? requestBody, String? responseBody, String? error, int retryCount = 0})
const

Properties

duration Duration?
no setter
endedAt DateTime?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
method String
final
requestBody String?
final
requestHeaders Map<String, String>
final
responseBody String?
final
responseHeaders Map<String, String>
final
retryCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
final
state DebugNetworkRequestState
final
statusCode int?
final
url Uri
final

Methods

copyWith({DateTime? endedAt, DebugNetworkRequestState? state, int? statusCode, Map<String, String>? requestHeaders, Map<String, String>? responseHeaders, Object? requestBody = _sentinel, Object? responseBody = _sentinel, Object? error = _sentinel}) DebugNetworkEntry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited